@@ -174,4 +174,6 @@ Moose meta method
 
 =cut
 
+__PACKAGE__->meta->make_immutable;
+no Moose;
 1;
