@@ -79,14 +79,14 @@ has 'xml' => (
 );
 has 'ScheduledDelivery' => (
     is      => 'ro',
-    isa     => 'Maybe[Date]',
+    isa     => 'Maybe[Business::UPS::Tracking::Type::Date]',
     traits  => ['Serializable'],
     lazy_build      => 1,
     documentation   => 'Scheduled delivery date',
 );
 has 'PickupDate' => (
     is      => 'ro',
-    isa     => 'Maybe[Date]',
+    isa     => 'Maybe[Business::UPS::Tracking::Type::Date]',
     traits  => ['Serializable'],
     documentation   => 'Pickup date',
     lazy_build      => 1,
@@ -223,5 +223,5 @@ Moose meta method
 
 
 __PACKAGE__->meta->make_immutable;
-
+no Moose;
 1;
\ No newline at end of file
