@@ -7,6 +7,7 @@ use 5.0100;
 use strict;
 use warnings;
 
+use Business::UPS::Tracking::Exception;
 use Moose::Util::TypeConstraints;
 use Business::UPS::Tracking;
 use MooseX::Getopt::OptionTypeMap;
@@ -35,9 +36,10 @@ coercions.
 
 =cut
 
-subtype 'XMLDocument' => as class_type('XML::LibXML::Document');
+subtype 'Business::UPS::Tracking::Type::XMLDocument' 
+    => as class_type('XML::LibXML::Document');
 
-coerce 'XMLDocument' 
+coerce 'Business::UPS::Tracking::Type::XMLDocument' 
     => from 'Str' 
     => via {
         my $xml = $_;
@@ -58,10 +60,10 @@ coerce 'XMLDocument'
         return $doc;
     };
     
-subtype 'Date' 
+subtype 'Business::UPS::Tracking::Type::Date' 
     => as class_type('DateTime');
 
-subtype 'DateStr' 
+subtype 'Business::UPS::Tracking::Type::DateStr' 
     => as 'Str' 
     => where {
         m/^ 
@@ -71,13 +73,13 @@ subtype 'DateStr'
         $/x;
     };
 
-coerce 'DateStr' 
-    => from 'Date' 
+coerce 'Business::UPS::Tracking::Type::DateStr' 
+    => from 'Business::UPS::Tracking::Type::Date' 
     => via {
         return $_->format_cldr('yyyyMMdd');
     };
 
-subtype 'TrackingNumber'
+subtype 'Business::UPS::Tracking::Type::TrackingNumber'
     => as 'Str'
     => where { 
         my $trackingnumber = $_;
@@ -107,7 +109,7 @@ subtype 'TrackingNumber'
     }
     => message { "Tracking numbers must start withn '1Z', contain 14 additional characters and end with a valid checksum" };
 
-subtype 'CountryCode'
+subtype 'Business::UPS::Tracking::Type::CountryCode'
     => as 'Str'
     => where { m/^[A-Z]{2}$/ }
     => message { "Must be an uppercase ISO 3166-1 alpha-2 code" };
